@@ -206,6 +206,8 @@ class ClientTestBase(testtools.TestCase):
             self.insecure = cloud_config.config['insecure']
         else:
             self.insecure = False
+        self.cacert = cloud_config.config['cacert']
+        self.cert = cloud_config.config['cert']
 
         auth = identity.Password(username=user,
                                  password=passwd,
@@ -213,7 +215,11 @@ class ClientTestBase(testtools.TestCase):
                                  auth_url=auth_url,
                                  project_domain_id=self.project_domain_id,
                                  user_domain_id=user_domain_id)
-        session = ksession.Session(auth=auth, verify=(not self.insecure))
+        session = ksession.Session(
+            cert=self.cert,
+            auth=auth,
+            verify=(self.cacert or not self.insecure)
+        )
 
         self.client = self._get_novaclient(session)
 
@@ -522,6 +528,27 @@ class ClientTestBase(testtools.TestCase):
         return {limit.name: limit.value
                 for limit in self.client.limits.get(reserved=True).absolute}
 
+    def _pick_alternate_flavor(self):
+        """Given the flavor picked in the base class setup, this finds the
+        opposite flavor to use for a resize test. For example, if m1.nano is
+        the flavor, then use m1.micro, but those are only available if Tempest
+        is configured. If m1.tiny, then use m1.small.
+        """
+        flavor_name = self.flavor.name
+        if flavor_name == 'm1.nano':
+            # This is an upsize test.
+            return 'm1.micro'
+        if flavor_name == 'm1.micro':
+            # This is a downsize test.
+            return 'm1.nano'
+        if flavor_name == 'm1.tiny':
+            # This is an upsize test.
+            return 'm1.small'
+        if flavor_name == 'm1.small':
+            # This is a downsize test.
+            return 'm1.tiny'
+        self.fail('Unable to find alternate for flavor: %s' % flavor_name)
+
 
 class TenantTestBase(ClientTestBase):
     """Base test class for additional tenant and user creation which
